@@ -64,6 +64,16 @@ from canalyst_candas.configuration.config import Config
 from canalyst_candas.settings import CONFIG
 
 
+def help():
+    print("Canalyst Candas help")
+    print(
+        "Please go to https://pypi.org/project/canalyst-candas/#description for installation help"
+    )
+    print("For support, please contact jed.gore@canalyst.com")
+    print("For an API KEY please go to https://app.canalyst.com/u/settings/api-tokens")
+    print("For an Excel model download:get_excel_model(ticker, config)")
+
+
 # helper class for on the fly function generation used in the ForecastFrame concept
 # where we try to change one param across multiple tickers for re-fit in the
 # scenario engine
@@ -107,7 +117,7 @@ class Search:
         print("unit types:currency, percentage, count, ratio, time")
         print("search_guidance_time_series syntax:")
         print(
-            "ticker (Bloomberg ticker),sector,item (time series description),item_name (time series name),most_recent (True or blank)"
+            "ticker (Bloomberg ticker),sector,time_series_description,time_series_name,most_recent (True or blank)"
         )
         return
 
@@ -115,23 +125,27 @@ class Search:
         self,
         ticker="",
         sector="",
-        Type="",
-        item="",
-        item_name="",
+        file_name="",
+        time_series_name="",
+        time_series_description="",
         most_recent="",
     ):
         if self.df_guidance is None:
             print("Building guidance index...")
-            self.df_guidance = Getter(config=self.config).get_csv_from_s3(
-                f"DATA/df_guidance.csv"
+            self.df_guidance = Getter(config=self.config).get_zip_csv_from_s3(
+                f"DATA/df_guidance.zip"
             )
             print("Done")
 
         df = self.df_guidance
 
+        df["time_series_description"] = df["Item"]
+        df["time_series_name"] = df["Item Name"]
+        df.drop(columns=["Item", "Item Name"])
+
         if most_recent == True:
             df = df.sort_values(["ticker", "Date"], ascending=False)
-            df = df.groupby(["ticker", "Item"]).first().reset_index()
+            df = df.groupby(["ticker", "time_series_name"]).first().reset_index()
 
         if type(ticker) == list:
             df = df.loc[df["ticker"].isin(ticker)]
@@ -140,14 +154,27 @@ class Search:
 
         if sector != "":
             df = df.loc[df["Path"].str.contains(sector, case=True, regex=True)]
-        if item != "":
-            df = df.loc[df["Item"].str.contains(item, case=False, regex=True)]
-        if item_name != "":
-            df = df.loc[df["item_name"].str.contains(item_name, case=False)]
+        if time_series_name != "":
+            df = df.loc[
+                df["time_series_name"].str.contains(
+                    time_series_name, case=False, regex=True
+                )
+            ]
+        if time_series_description != "":
+            df = df.loc[
+                df["time_series_description"].str.contains(
+                    time_series_description, case=False
+                )
+            ]
+
+        if file_name != "":
+            df = df.loc[df["Filename"].str.contains(file_name, case=False)]
+
         return df[
             [
                 "ticker",
                 "Path",
+                "Filename",
                 "Item",
                 "Item Name",
                 "Fiscal Period",
@@ -168,12 +195,14 @@ class Search:
         time_series_description="",
         category="",
         is_driver="",
+        file_name="",
         unit_type="",
     ):
+        pd.options.mode.chained_assignment = None
         if self.df_search is None:
             print("Building search index...")
-            self.df_search = Getter(config=self.config).get_csv_from_s3(
-                f"DATA/df_search.csv"
+            self.df_search = Getter(config=self.config).get_zip_csv_from_s3(
+                f"DATA/df_search.zip"
             )
             print("Done")
 
@@ -196,7 +225,7 @@ class Search:
         if time_series_description != "":
             df = df.loc[
                 df["time_series_description"].str.contains(
-                    time_series_description, case=False
+                    time_series_description, case=False, regex=True
                 )
             ]
         if is_driver != "":
@@ -205,6 +234,10 @@ class Search:
             df = df.loc[
                 df["unit_type"] == unit_type
             ]  # currency, percentage, count, ratio, time
+
+        if file_name != "":
+            df = df.loc[df["Filename"].str.contains(file_name, case=False)]
+
         df["fiscal_or_annual"] = np.where(
             df["value"].isna(), "fiscal_year", "fiscal_quarter"
         )
@@ -212,6 +245,7 @@ class Search:
             [
                 "ticker",
                 "Path",
+                "Filename",
                 "category",
                 "time_series_description",
                 "time_series_name",
@@ -708,6 +742,8 @@ class ModelSet:
             "model_frame": "Return a dataframe of the full modelset. params: time_series_name,period_name,is_driver='',pivot=False,mrq=False,period_duration_type='',is_historical='',n_periods='',mrq_notation=False",
             "forecast_frame": "Return a params dataframe for use in the fit function. params: time_series_name, n_periods, function_name='value', function_value='' where function name can be add, subtract, multiply, divide, or value",
             "fit": "Return a return series for a fitted model. params: params dataframe, return_series.  params dataframe columns are: ticker period time_series_name value new_value",
+            "model_set.models[Bloomberg Ticker].get_excel_model_name()": "Return most recent model name for a ticker",
+            "model_set.models[Bloomberg Ticker].get_most_recent_model_date()": "Return most recent model upload date for a ticker",
         }
         if function_name != "":
             return dict_help[function_name]
@@ -909,6 +945,7 @@ class ModelSet:
         is_historical="",
         n_periods="",
         mrq_notation=False,
+        unit_type="",
         warning=True,
         ticker="",
     ):
@@ -929,6 +966,7 @@ class ModelSet:
             is_historical,
             n_periods,
             mrq_notation,
+            unit_type,
             warning,
         )
 
@@ -1448,7 +1486,9 @@ class Model:
         force=False,
         extract_drivers=True,
         historical_only=False,
+        model_name=False,
     ):
+        self.model_name = model_name
         self.config = config or CONFIG
         self.historical_only = historical_only
         self.ticker = ticker
@@ -1495,8 +1535,57 @@ class Model:
             print("guidance")
             self.create_guidance_csv()
 
-        self._model_name = self.get_excel_model_name()
-        self._model_frame["model_name"] = self._model_name
+        if self.model_name == True:
+            self._model_name = self.get_excel_model_name()
+            self._model_frame["model_name"] = self._model_name
+
+    def get_most_recent_model_date(self):
+
+        csin = self.csin
+        auth_headers = self.api_headers
+        mds_host = self.config.mds_host
+        wp_host = self.config.wp_host
+
+        from python_graphql_client import GraphqlClient
+
+        client = GraphqlClient(endpoint=f"{wp_host}/model-workbooks")
+
+        # Create the query string and variables required for the request.
+        query = """
+        query driversWorksheetByCSIN($csin: ID!) {
+            modelSeries(id: $csin) {
+            latestModel {
+                id
+                name
+                publishedAt
+                variantsByDimensions(
+                    driversWorksheets: [STANDARD_FCF],
+                    periodOrder: [CHRONOLOGICAL],
+                ) {
+                id
+                downloadUrl
+                variantDimensions {
+                    driversWorksheets
+                    periodOrder
+                }
+                }
+            }
+            }
+        }
+        """
+        variables = {"csin": csin}
+
+        # Synchronous request
+        data = client.execute(
+            query=query, variables=variables, headers=auth_headers, verify=False
+        )
+        url = data["data"]["modelSeries"]["latestModel"]["variantsByDimensions"][0][
+            "downloadUrl"
+        ]
+        file_ticker = self.ticker.split(" ")[0]
+        date_name = data["data"]["modelSeries"]["latestModel"]["publishedAt"]
+        date_name = date_name.split("T")[0]
+        return date_name
 
     def get_excel_model_name(self):
 
@@ -1732,6 +1821,7 @@ class Model:
                         open(f"{path_name}" + filename, "rb"),
                         index_col=False,
                         sheet_name="Guidance",
+                        engine="openpyxl",
                     )
                 except:
                     self.log.write("guidance: Excel read error")
@@ -1890,6 +1980,7 @@ class Model:
         is_historical="",
         n_periods=12,
         mrq_notation=False,
+        unit_type="",
         warning=True,
     ):
         return filter_dataset(
@@ -1903,6 +1994,7 @@ class Model:
             is_historical,
             n_periods,
             mrq_notation,
+            unit_type,
             warning,
         )
 
